==> easysciencecore-0.4.0.tar.gz: easysciencecore-0.4.0/README.md <==
# [![License][50]][51] [![Release][32]][33] [![Downloads][70]][71] [![CI Build][20]][21] 

[![CodeFactor][83]][84] [![Codecov][85]][86]
[![Lines of code][81]](<>) [![Total lines][80]](<>) [![Files][82]](<>)


<img height="80"><img src="https://raw.githubusercontent.com/easyScience/easyCore/main/resources/images/ec_logo.svg" height="65">

**easyCore** is the foundation of the *easyScience* universe, providing the building blocks for libraries and applications which aim to make scientific data simulation and analysis easier.

## Install

**easyCore** can be downloaded using pip:

```pip install easysciencecore```

Or direct from the repository:

```pip install https://github.com/easyScience/easyCore```

## Test

After installation, launch the test suite:

```python -m pytest```

## Documentation

Documentation can be found at:

[https://easyScience.github.io/easyCore](https://easyScience.github.io/easyCore)

## Contributing
We absolutely welcome contributions. **easyCore** is maintained by the ESS and on a volunteer basis and thus we need to foster a community that can support user questions and develop new features to make this software a useful tool for all users while encouraging every member of the community to share their ideas.

## License
While **easyCore** is under the BSD-3 license, DFO_LS is subject to the GPL license.

<!---CI Build Status--->

[20]: https://github.com/easyScience/easyCore/workflows/CI%20using%20pip/badge.svg

[21]: https://github.com/easyScience/easyCore/actions


<!---Release--->

[32]: https://img.shields.io/pypi/v/easysciencecore?color=green

[33]: https://pypi.org/project/easyScienceCore


<!---License--->

[50]: https://img.shields.io/github/license/easyScience/easyCore.svg

[51]: https://github.com/easyScience/easyCore/blob/main/LICENSE.md


<!---Downloads--->

[70]: https://img.shields.io/pypi/dm/easyScienceCore.svg

[71]: https://pypi.org/project/easyScienceCore

<!---Code statistics--->

[80]: https://tokei.rs/b1/github/easyScience/easyCore

[81]: https://tokei.rs/b1/github/easyScience/easyCore?category=code

[82]: https://tokei.rs/b1/github/easyScience/easyCore?category=files

[83]: https://www.codefactor.io/repository/github/easyscience/easycore/badge

[84]: https://www.codefactor.io/repository/github/easyscience/easycore

[85]: https://img.shields.io/codecov/c/github/easyScience/easyCore?color=green

[86]: https://app.codecov.io/gh/easyScience/easyCore/

==> easysciencecore-0.5.0.tar.gz: easysciencecore-0.5.0/README.md <==
# [![License][50]][51] [![Release][32]][33] [![Downloads][70]][71] [![CI Build][20]][21] 

[![CodeFactor][83]][84] [![Codecov][85]][86]
[![Lines of code][81]](<>) [![Total lines][80]](<>) [![Files][82]](<>)


<img height="80"><img src="https://raw.githubusercontent.com/easyScience/easyCore/main/resources/images/ec_logo.svg" height="65">

**easyCore** is the foundation of the *easyScience* universe, providing the building blocks for libraries and applications which aim to make scientific data simulation and analysis easier.

## Install

**easyCore** can be downloaded using pip:

```pip install easysciencecore```

Or direct from the repository:

```pip install https://github.com/easyScience/easyCore```

## Test

After installation, launch the test suite:

```python -m pytest```

## Documentation

Documentation can be found at:

[https://easyScience.github.io/easyCore](https://easyScience.github.io/easyCore)

## Contributing
We absolutely welcome contributions. **easyCore** is maintained by the ESS and on a volunteer basis and thus we need to foster a community that can support user questions and develop new features to make this software a useful tool for all users while encouraging every member of the community to share their ideas.

## License
While **easyCore** is under the BSD-3 license, DFO_LS is subject to the GPL license.

<!---CI Build Status--->

[20]: https://github.com/easyScience/easyCore/workflows/CI%20using%20pip/badge.svg

[21]: https://github.com/easyScience/easyCore/actions/workflows/python-ci.yml


<!---Release--->

[32]: https://img.shields.io/pypi/v/easysciencecore?color=green

[33]: https://pypi.org/project/easyScienceCore


<!---License--->

[50]: https://img.shields.io/github/license/easyScience/easyCore.svg

[51]: https://github.com/easyScience/easyCore/blob/main/LICENSE.md


<!---Downloads--->

[70]: https://img.shields.io/pypi/dm/easyScienceCore.svg

[71]: https://pypi.org/project/easyScienceCore

<!---Code statistics--->

[80]: https://tokei.rs/b1/github/easyScience/easyCore

[81]: https://tokei.rs/b1/github/easyScience/easyCore?category=code

[82]: https://tokei.rs/b1/github/easyScience/easyCore?category=files

[83]: https://www.codefactor.io/repository/github/easyscience/easycore/badge

[84]: https://www.codefactor.io/repository/github/easyscience/easycore

[85]: https://img.shields.io/codecov/c/github/easyScience/easyCore?color=green

[86]: https://app.codecov.io/gh/easyScience/easyCore/
